      SUBROUTINE CALC_RESIS_FLOW(NBJ,NEELEM,NENP,nh,NPNE,NVJE,NYNE,
     '  RESISNE,INERTNE,XP,YP,ERROR,*)

C#### Subroutine: CALC_RESIS_FLOW
C###  Description:  Calculates airway resistance only at the moment
C#### Equation from Anafi and Wilson,  J.Appl.Physiol,91:1185-1192,2001
C###  Created by KLH April 2003
C     Correction addded for turbulent flow in bifurcation.  See Pedley
C     et al.       
      
      IMPLICIT NONE
      INCLUDE 'b00.cmn'
      INCLUDE 'geom00.cmn'
      INCLUDE 'lung00.cmn'
      INCLUDE 'pulm00.cmn'
      INCLUDE 'tol00.cmn'

!     Parameter List
      INTEGER NBJ(NJM,NEM),NEELEM(0:NE_R_M),NENP(NPM,0:NEPM),
     '  nh,NPNE(NNM,NBFM,NEM),NVJE(NNM,NBFM,NJM,NEM),
     '  NYNE(NAM,NHM,0:NRCM,NCM,NEM)
      REAL*8 RESISNE(NE_R_M),INERTNE(NE_R_M),XP(NKM,NVM,NJM,NPM),YP(NYM)
      CHARACTER ERROR*(*)

!     Local Variables
      INTEGER na,nb,ne,next,nj,noelem,np1,np2,nv1,nv2,ny
      REAL*8 area,avrad,blength,dens,elength,length,reynolds,
     '  visc,zeta
      LOGICAL end1,end2

      CALL ENTERS('CALC_RESIS_FLOW',*9999)

c      visc=1.9d-6
c      dens=1.13d-7
      visc=1.820d-5 !in g.mm-1.s-1
      dens=1.127d-6 !in g.mm-3

      CALL ASSERT(nj_radius.GT.0,'define radius values first',ERROR,
     &  *9999)

      DO noelem=1,NEELEM(0)
        end1=.FALSE.
        end2=.FALSE.
        length=0.d0
        ne=NEELEM(noelem)
        nb=NBJ(1,ne)
        np1=NPNE(1,nb,ne)
        np2=NPNE(2,nb,ne)
        nv1=NVJE(1,nb,nj_radius,ne)
        nv2=NVJE(2,nb,nj_radius,ne)
        avrad=0.5d0*(XP(1,nv1,nj_radius,np1)+XP(1,nv2,nj_radius,np2))
        CALL ASSERT(DABS(avrad).GT.ZERO_TOL,
     &  '>> zero radii: set radius values correctly',ERROR,*9999)
        area=pi*avrad**2.d0
        na=1 !for FLOW
        ny=NYNE(na,nh,1,1,ne) !ny for for flow
c        ce(5,ne)=yp(ny)  !Temp put in for export of flow results
c        ce(17,ne)=avrad  !Temp put in for export of radius results
        reynolds=DABS(YP(ny))*avrad*2.d0*dens/(area*visc)
        DO nj=1,NJT
          length=length+(XP(1,1,nj,np1)-XP(1,1,nj,np2))**2.d0
        ENDDO
        elength=DSQRT(length)
        length=0.d0
c  Commented out.  Need to check turbulence calculations        
c        DO WHILE(.NOT.end1)
c          IF(NENP(np1,0).EQ.2)THEN
c            next=NENP(np1,1) !stores next elem in branch for turbulence calculation
c            np1=NPNE(1,nb,next)
c          ELSE
c            end1=.TRUE.
c          ENDIF
c        ENDDO
c        DO WHILE(.NOT.end2)
c          IF(NENP(np2,0).EQ.2)THEN
c            next=NENP(np2,2) !stores next elem in branch for turbulence calculation
c            np2=NPNE(2,nb,next)
c          ELSE
c            end2=.TRUE.
c          ENDIF
c        ENDDO
c Calculation of branch length to end of current element        
        DO nj=1,NJT
          length=length+(XP(1,1,nj,np1)-XP(1,1,nj,np2))**2.d0
        ENDDO
        blength=DSQRT(length)
        zeta=DSQRT(2.d0*avrad*reynolds/blength)*1.85d0/(4.d0
     &    *DSQRT(2.d0))
        IF(zeta.LT.1.d0) then
c          write(*,*)'zeta less than 1',zeta
          zeta=1.d0
        endif
        CALL ASSERT(nj_radius.GT.0,'>> set radius values first',ERROR,
     &  *9999)
        RESISNE(ne)=128.0d0*elength*visc/(pi*(2.d0*avrad)**4.d0)*zeta !Turbulent Resistance
c        CE(4,ne)=128.0d0*elength*visc/(pi*(2.d0*avrad)**4.d0) !Turbulent Resistance
c        write(*,*) elength,avrad,CE(4,ne),reynolds
C	Want to have complex impedance - flow resistance (real) + compliance (-imag) + inertance (+imag)
C	Can compute compliance from gas compression + wall compliance assumptions/parameters
C	Compute inertance from gas density and velocity (ie frequency dependent)
	INERTNE(ne) = elength * dens / (pi * avrad**2.d0) 
      ENDDO

      CALL EXITS('CALC_RESIS_FLOW')
      RETURN
 9999 CALL ERRORS('CALC_RESIS_FLOW',ERROR)
      CALL EXITS('CALC_RESIS_FLOW')
      RETURN 1
      END

